==> django-github-s3-0.17.tar.gz: django-github-s3-0.17/README.md <==
# django-github-s3

### Installation
Installing from PyPi:
        
        $ pip install django-github-s3
        
Once the installation is done, setup the following in the settings.py file.

       DEFAULT_FILE_STORAGE = "github_storages.backend.BackendStorages"
       GITHUB_HANDLE = "Your Github Handle"
       ACCESS_TOKEN = "Your Github Access Token"
       GITHUB_REPO_NAME = "Your New Github Repository Name"


If you are using ImageField or FileField then do not specify upload_to parameters
      
       photo = models.ImageField(upload_to="pics/", null=True, blank=True)

Set it to just:
        
       photo = models.ImageField(null=True, blank=True)
       
## About
django-github-s3 is a project to provide beginners a storage backend on github for free.

Since other simple-storage-services requires credit-card information to setup an account and get started. 
There is a lot of traction in between for the beginners. 

Therefore django-github-s3 helps beginners to store the media files on github with very less number of steps required in the initial setup.

## Found a Bug? Something Unsupported?
Issues are tracked via GitHub issues at the [project issue page](https://github.com/vivekchandrabs/django-github-s3/issues).

## Contributing

 1. [Check for open issues](https://github.com/vivekchandrabs/django-github-s3/issues) at the project issues page or open a new issues to start a discussion about a feature or bug
 2. Fork the [django-github-s3 repository on GitHub](https://github.com/vivekchandrabs/django-github-s3) to start making changes in your own branch.

==> django-github-s3-0.18.tar.gz: django-github-s3-0.18/README.md <==
# django-github-s3

### Installation
Installing from PyPi:
        
        $ pip install django-github-s3
        
Once the installation is done, setup the following in the settings.py file.

       DEFAULT_FILE_STORAGE = "github_storages.backend.BackendStorages"
       GITHUB_HANDLE = "Your Github Handle"
       ACCESS_TOKEN = "Your Github Access Token"
       GITHUB_REPO_NAME = "Your New Github Public Repository Name"


If you are using ImageField or FileField then do not specify upload_to parameters
      
       photo = models.ImageField(upload_to="pics/", null=True, blank=True)

Set it to just:
        
       photo = models.ImageField(null=True, blank=True)
       
## About
django-github-s3 is a project to provide beginners a storage backend on github for free.

Since other simple-storage-services requires credit-card information to setup an account and get started. 
There is a lot of traction in between for the beginners. 

Therefore django-github-s3 helps beginners to store the media files on github with very less number of steps required in the initial setup.

## Found a Bug? Something Unsupported?
Issues are tracked via GitHub issues at the [project issue page](https://github.com/vivekchandrabs/django-github-s3/issues).

## Contributing
 1. [Check for open issues](https://github.com/vivekchandrabs/django-github-s3/issues) at the project issues page or open a new issues to start a discussion about a feature or bug
 2. Fork the [django-github-s3 repository on GitHub](https://github.com/vivekchandrabs/django-github-s3) to start making changes in your own branch.
 
## Warning !!!
The github repository that you have to create should be public. Storing any confidential information is not recommanded.
